@@ -1,22 +1,7 @@
-/***************************************************************************
- *   Copyright (C) 2012 by                                                 *
- *   Joris Guisson <joris.guisson@gmail.com>                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2012 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include <KConfigGroup>
 
@@ -52,7 +37,7 @@ GroupSwitcher::GroupSwitcher(View *view, GroupManager *gman, QWidget *parent)
     layout->addWidget(edit_group_policy);
     layout->addWidget(tool_bar);
     layout->addWidget(close_tab);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
 
     new_tab->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
     new_tab->setToolButtonStyle(Qt::ToolButtonIconOnly);
