@@ -1,23 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2007 by Joris Guisson and Ivan Vasic                    *
- *   joris.guisson@gmail.com                                               *
- *   ivasic@gmail.com                                                      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-FileCopyrightText: 2007 Ivan Vasic <ivasic@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "torrentfilelistmodel.h"
 
@@ -261,11 +246,11 @@ bt::Uint64 TorrentFileListModel::bytesToDownload()
 bt::TorrentFileInterface *TorrentFileListModel::indexToFile(const QModelIndex &idx)
 {
     if (!tc || !idx.isValid())
-        return 0;
+        return nullptr;
 
     int r = idx.row();
     if (r >= rowCount(QModelIndex()))
-        return 0;
+        return nullptr;
     else
         return &tc->getTorrentFile(r);
 }
