@@ -48,10 +48,10 @@ FileView::FileView(QWidget *parent)
     , header_state_loaded(false)
 {
     QHBoxLayout *layout = new QHBoxLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing(0);
     QVBoxLayout *vbox = new QVBoxLayout();
-    vbox->setMargin(0);
+    vbox->setContentsMargins(0, 0, 0, 0);
     vbox->setSpacing(0);
     view = new QTreeView(this);
     toolbar = new QToolBar(this);
