@@ -1,23 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2008 by Joris Guisson and Ivan Vasic                    *
- *   joris.guisson@gmail.com                                               *
- *   ivasic@gmail.com                                                      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-FileCopyrightText: 2008 Ivan Vasic <ivasic@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "peerviewmodel.h"
 
@@ -28,10 +13,13 @@
 #include <KLocalizedString>
 
 #include "flagdb.h"
-#include "geoipmanager.h"
 #include <interfaces/torrentinterface.h>
 #include <util/functions.h>
 
+#if BUILD_WITH_GEOIP
+#include "geoipmanager.h"
+#endif
+
 using namespace bt;
 
 namespace kt
@@ -40,7 +28,12 @@ static QIcon yes, no;
 static bool icons_loaded = false;
 static FlagDB flagDB(22, 18);
 
-PeerViewModel::Item::Item(bt::PeerInterface *peer, GeoIPManager *geo_ip)
+PeerViewModel::Item::Item(bt::PeerInterface *peer
+#if BUILD_WITH_GEOIP
+                          ,
+                          GeoIPManager *geo_ip
+#endif
+                          )
     : peer(peer)
 {
     stats = peer->getStats();
@@ -54,13 +47,13 @@ PeerViewModel::Item::Item(bt::PeerInterface *peer, GeoIPManager *geo_ip)
             flagDB.addFlagSource(path + QStringLiteral("/%1/flag.png"));
     }
 
-    if (geo_ip) {
-        int country_id = geo_ip->findCountry(stats.ip_address);
-        if (country_id > 0) {
-            country = geo_ip->countryName(country_id);
-            flag = flagDB.getFlag(geo_ip->countryCode(country_id));
-        }
+#if BUILD_WITH_GEOIP
+    int country_id = geo_ip->findCountry(stats.ip_address);
+    if (country_id > 0) {
+        country = geo_ip->countryName(country_id);
+        flag = flagDB.getFlag(geo_ip->countryCode(country_id));
     }
+#endif
 }
 
 bool PeerViewModel::Item::changed() const
@@ -198,9 +191,10 @@ QVariant PeerViewModel::Item::decoration(int col) const
 
 PeerViewModel::PeerViewModel(QObject *parent)
     : QAbstractTableModel(parent)
-    , geo_ip(nullptr)
 {
+#if BUILD_WITH_GEOIP
     geo_ip = new GeoIPManager(this);
+#endif
 }
 
 PeerViewModel::~PeerViewModel()
@@ -210,7 +204,12 @@ PeerViewModel::~PeerViewModel()
 
 void PeerViewModel::peerAdded(bt::PeerInterface *peer)
 {
-    items.append(new Item(peer, geo_ip));
+    items.append(new Item(peer
+#if BUILD_WITH_GEOIP
+                          ,
+                          geo_ip
+#endif
+                          ));
     insertRow(items.count() - 1);
 }
 
