@@ -22,12 +22,11 @@ class MediaPlayerPlugin : public Plugin
 {
     Q_OBJECT
 public:
-    MediaPlayerPlugin(QObject *parent, const QVariantList &args);
+    MediaPlayerPlugin(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
     ~MediaPlayerPlugin() override;
 
     void load() override;
     void unload() override;
-    bool versionCheck(const QString &version) const override;
 
 private:
     MediaPlayerActivity *act;
