@@ -29,7 +29,7 @@
 #include <util/log.h>
 #include <util/logsystemmanager.h>
 
-K_PLUGIN_FACTORY_WITH_JSON(ktorrent_search, "ktorrent_search.json", registerPlugin<kt::SearchPlugin>();)
+K_PLUGIN_CLASS_WITH_JSON(kt::SearchPlugin, "ktorrent_search.json")
 
 using namespace bt;
 
